<?php

namespace App\Http\Controllers;

use App\Models\Employee;
use App\Models\Timesheet;
use App\Models\TimesheetImage;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use function PHPUnit\Framework\isNull;

class TimeSheetController extends Controller
{
    public function __construct(){
        $this->middleware('RedirectIfNotAuthenticate', ['except'=>['validateTimesheetDate','saveTimesheetImageDataStructure']]);
    }

    public function index(Request $request)
    {
        $query = Timesheet::query();

        // Join with the Employee table to get employee details
        $query->join('employees', 'timesheets.employee_id', '=', 'employees.id')
            ->select('timesheets.*', DB::raw("CONCAT(employees.first_name, ' ', employees.last_name) as employee_name"));

        // Filter by employee name
        if ($request->filled('employee_name')) {
            $query->where(DB::raw("CONCAT(employees.first_name, ' ', employees.last_name)"), 'like', '%' . $request->employee_name . '%');
        }

        // Filter by date range
        if ($request->filled('from_date')) {
            $query->whereDate('work_date', '>=', $request->from_date);
        }

        if ($request->filled('to_date')) {
            $query->whereDate('work_date', '<=', $request->to_date);
        }

        // Get the paginated results
        $timesheets = $query->orderBy('work_date', 'desc')->paginate(10);
        //return $timesheets;
        return view('timesheet.index', compact('timesheets'));
    }

    public function createTimeSheet(){
        $employees = Employee::select(DB::raw("CONCAT(first_name, ' ', last_name) AS full_name"), 'id')
            ->with(['latestTimesheet' => function ($query) {
                $query->select('employee_id', 'ssn', 'work_classification')
                    ->latest();
            }])->get();

        // Map the data to include full_name, id, last submitted ssn, and work_classification
        $employees = $employees->map(function ($employee) {
            return [
                'id' => $employee->id,
                'full_name' => $employee->full_name,
                'ssn' => optional($employee->latestTimesheet)->ssn,
                'work_classification' => optional($employee->latestTimesheet)->work_classification
            ];
        });
        //return $employees;
        return view('timesheet.create', compact('employees'));
    }


    public function store(Request $request){
        $workDate = Carbon::parse($request->work_date)->format('Y-m-d');
        $employeeIds = $request->employee_id;
        if(is_array($employeeIds)){
            foreach($employeeIds as $i =>$employeeId){
                Timesheet::create([
                    'company_name' => $request->company_name,
                    'development' => $request->development,
                    'contractor' => $request->contractor,
                    'work_date' => $workDate,
                    'contract_no' => $request->contract_no,
                    'employee_id' => $employeeId,
                    'work_classification' => $request->work_classification[$i],
                    'ssn' => $request->ssn[$i],
                    'time_in' => $request->time_in[$i],
                    'time_out' => $request->time_out[$i]
                ]);
            }
        }
        return redirect('module/timesheet');
    }

    public function editTimeSheet($id)
    {
        // Fetch the timesheet by ID
        $timesheet = Timesheet::with('employee')->findOrFail($id);

        // Get all employees for the dropdown list
        $employees = Employee::select(DB::raw("CONCAT(first_name, ' ', last_name) AS full_name"), 'id')->get();

        // Pass the timesheet and employees data to the view
        return view('timesheet.edit', compact('timesheet', 'employees'));
    }

    public function timeSheetWithAi(){
        $allEmployees = Employee::all(['id', 'first_name', 'last_name']);

        return view('timesheet.timesheet_with_ai', compact('allEmployees'));
    }

    public function saveAiGeneratedTimeSheetData($timesheetImageId, Request $request) {
        $workDate = Carbon::parse($request->work_date)->format('Y-m-d');

        // Prepare the structure to store in verified_structure
        $verifiedStructure = [
            "development_name" => $request->development,
            "date" => $workDate,
            "contract_no" => $request->contract_no,
            "contractor" => $request->contractor,
            "employees" => []
        ];

        // Track timesheet IDs submitted
        $submittedTimesheetIds = array_filter($request->timesheet_id);

        if (is_array($request->employee_name)) {
            foreach ($request->employee_name as $i => $employeeName) {
                $employeeId = $request->employee_id[$i];
                $timesheetId = $request->timesheet_id[$i] ?? null;

                // Create employee if necessary
                if (is_null($employeeId)) {
                    $nameParts = explode(' ', $employeeName, 2);
                    $firstName = ucfirst(strtolower($nameParts[0]));
                    $lastName = isset($nameParts[1]) ? ucfirst(strtolower($nameParts[1])) : '';

                    $employee = Employee::create([
                        'first_name' => $firstName,
                        'last_name' => $lastName,
                    ]);
                    $employeeId = $employee->id;
                }

                // Insert or update timesheet based on timesheet_id
                $timesheetData = [
                    'company_name' => $request->company_name,
                    'development' => $request->development,
                    'contractor' => $request->contractor,
                    'work_date' => $workDate,
                    'contract_no' => $request->contract_no,
                    'employee_id' => $employeeId,
                    'work_classification' => $request->work_classification[$i],
                    'ssn' => $request->ssn[$i],
                    'time_in' => $request->time_in[$i],
                    'time_out' => $request->time_out[$i],
                    'timesheet_image_id' => $timesheetImageId
                ];

                if ($timesheetId) {
                    // Update existing timesheet
                    Timesheet::where('id', $timesheetId)->update($timesheetData);
                } else {
                    // Create a new timesheet
                    $timesheet = Timesheet::create($timesheetData);
                    $timesheetId = $timesheet->id;
                }

                // Append employee data to the verified structure, including Timesheet ID
                $verifiedStructure["employees"][] = [
                    "name" => $employeeName,
                    "employee_id" => $employeeId,
                    "timesheet_id" => $timesheetId,
                    "work_classification" => $request->work_classification[$i],
                    "ssn_last_4_digits" => $request->ssn[$i],
                    "time_in" => $request->time_in[$i],
                    "time_out" => $request->time_out[$i],
                ];
            }
        }

        // Delete timesheets that were not included in the submitted data
        Timesheet::where('timesheet_image_id', $timesheetImageId)
            ->whereNotIn('id', $submittedTimesheetIds)
            ->delete();

        // Save the verified structure in the verified_structure column as JSON
        TimesheetImage::find($timesheetImageId)->fill([
            'verified_by' => auth()->user()->id,
            'verified_structure' => json_encode($verifiedStructure),
        ])->save();

        return redirect('module/timesheet/uploaded_timesheet_list')->with('success', 'Timesheet data saved successfully with verified structure.');
    }


    public function getUploadTimesheet(){
        return view('timesheet.upload_timesheet');
    }

    public function saveTimesheetImageDataStructure(Request $request){
        $timesheetImage = new TimesheetImage();
        $timesheetImage->image = $request->image_path;
        $timesheetImage->ai_generated_structure = $request->structured_data;  // Save the JSON structure
        $timesheetImage->structured_uploaded_by = $request->user_id;
        $timesheetImage->timesheet_date = Carbon::createFromFormat('m-d-Y', $request->timesheet_date)->format('Y-m-d');
        $timesheetImage->remarks = $request->remarks;
        $timesheetImage->save();
        return response()->json([
            'structured_data' => $timesheetImage,
        ]);
    }

    public function getUploadedTimeSheetList(Request $request)
    {
        $query = TimesheetImage::orderBy('id', 'desc');
        // Filter by date if provided
        if ($request->has('date') && $request->date) {
            $query->whereDate('timesheet_date', Carbon::createFromFormat('m-d-Y', $request->date)->format('Y-m-d'));
        }

        $timesheetImages = $query->paginate(20);
        $timesheetImages->each(function($item){
           return $item->image = env('IMAGE_URL').'/'.$item->image;
        });
        //return $timesheetImages;

        return view('timesheet.uploaded_timesheet_list', compact('timesheetImages'));
    }

    public function validateTimesheetDate($timesheetDate){
        $status = TimesheetImage::where('timesheet_date', $timesheetDate)->first();
        if(!$status){
            return [
                'success' => true,
                'message' => 'Provided User ID and Date of Time-Sheet allowed'
            ];
        }else{
            return [
                'success' => false,
                'message' => 'Data already exist'
            ];
        }
    }

    public function checkEmployeesBySSN(Request $request)
    {
        // Get the SSNs from the request
        $ssns = $request->input('ssns');

        // Query the timesheets table to find employees by SSN
        $employees = Timesheet::whereIn('ssn', $ssns)
            ->with('employee:id,first_name,last_name') // Assuming relationship to Employee model
            ->get(['employee_id', 'ssn', 'work_classification']);

        // Format the response
        $response = $employees->map(function ($timesheet) {
            return [
                'ssn' => $timesheet->ssn,
                'name' => $timesheet->employee->first_name . ' ' . $timesheet->employee->last_name,
                'employee_id' => $timesheet->employee_id,
                'work_classification' => $timesheet->work_classification
            ];
        });

        return response()->json($response);
    }

    public function get_employee_suggestions(Request $request){
        $query = $request->q;

        $data = Employee::leftJoin('timesheets', function ($join) {
            $join->on('employees.id', '=', 'timesheets.employee_id')
                ->whereRaw('timesheets.work_date = (select max(t2.work_date) from timesheets t2 where t2.employee_id = timesheets.employee_id)');
        })->where(function($queryBuilder) use ($query) {
                $queryBuilder->where('employees.first_name', 'LIKE', '%' . $query . '%')
                    ->orWhere('employees.last_name', 'LIKE', '%' . $query . '%');
        })->select('employees.id', 'employees.first_name', 'employees.last_name', 'timesheets.ssn', 'timesheets.work_classification')
            ->get();

        // Format the result to be used in autocomplete
        $data->each(function($item) {
            $item->value = $item->id;
            $item->text = $item->first_name . ' ' . $item->last_name;
        });

        return $data->toArray();
    }

    public function deleteUploadedTimesheet($id){
        $timesheet = TimesheetImage::findOrFail($id);
        $timesheet->delete();
        return redirect('module/timesheet/uploaded_timesheet_list')->with('success', 'Timesheet deleted successfully.');
    }

    public function verifyDataStructure($timesheetImageId){
        $allEmployees = Employee::all(['id', 'first_name', 'last_name']);
        $timesheetImage = TimesheetImage::find($timesheetImageId);
        $timesheetImage->image = env('IMAGE_URL').'/'.$timesheetImage->image;
        // change this logic. if verify_structure is null then take ai_generated_structure else take verify_structure;
        // Remember if we take the verify_structure then definately we will need to update the Timesheet on the saveAiGeneratedTimeSheetData function.
        if($timesheetImage->verified_structure === null){
            $timesheetImage->structure = json_decode($timesheetImage->ai_generated_structure) ?? [];
        }else{
            $timesheetImage->structure = json_decode($timesheetImage->verified_structure) ?? [];
        }
        return view('timesheet.verify_data_structure', compact('allEmployees','timesheetImage'));
    }




}
